//
//  ElapsedTimeView.swift
//  CapstoneProject WatchKit Extension
//
//  Created by Easten Wember on 2/25/22.
//

import SwiftUI

struct ElapsedTimeView: View {
    var elapsedTime: TimeInterval = 0 //default time of workout start at 0
    var showSubseconds: Bool = true
    @State private var timeFormatter = ElapsedTimeFormatter()

    var body: some View {
        Text(NSNumber(value: elapsedTime), formatter: timeFormatter) //cast elapsed time to NSNumber so timeFormatter can use it
            .fontWeight(.semibold)
            .onChange(of: showSubseconds) {
                timeFormatter.showSubseconds = $0
            }
    }
}

class ElapsedTimeFormatter: Formatter {
    let componentsFormatter: DateComponentsFormatter = {
        let formatter = DateComponentsFormatter()
        formatter.allowedUnits = [.minute, .second] //show min and seconds
        formatter.zeroFormattingBehavior = .pad //pad 0s
        return formatter
    }()
    
    var showSubseconds = true //show sub seconds!

    override func string(for value: Any?) -> String? {
        guard let time = value as? TimeInterval else { //ensure value is time interval
            return nil
        }

        guard let formattedString = componentsFormatter.string(from: time) else { //ensure string us retuned by components form
            return nil
        }

        if showSubseconds {
            let hundredths = Int((time.truncatingRemainder(dividingBy: 1)) * 100) //calculate subseconds
            let decimalSeparator = Locale.current.decimalSeparator ?? "."
            return String(format: "%@%@%0.2d", formattedString, decimalSeparator, hundredths) //append subseconds
        }

        return formattedString //if showSubSecondsFalse, just return formatted string  w/o subseconds
    }
}

struct ElapsedTime_Previews: PreviewProvider {
    static var previews: some View {
        ElapsedTimeView()
    }
}

