//
//  MetricsView.swift
//  CapstoneProject WatchKit Extension
//
//  Created by Easten Wember on 2/25/22.
//

import SwiftUI
import HealthKit
import OSLog

struct MetricsView: View {
    @EnvironmentObject var workoutManager: WorkoutManager
    
    var body: some View {
        TimelineView(MetricsTimelineSchedule(from: workoutManager.builder?.startDate ?? Date())) { context in
            ScrollView { //? need to check to see if can scroll
                VStack(alignment: .leading) {
                    ElapsedTimeView(elapsedTime: workoutManager.builder?.elapsedTime ?? 0, showSubseconds: context.cadence == .live) //add ElapsedTimeView instance to MetricsView
                        .foregroundStyle(.yellow)
                    
                    Text(Measurement(value: workoutManager.activeEnergy, unit: UnitEnergy.kilocalories)
                            .formatted(.measurement(width: .abbreviated, usage: .workout, numberFormatStyle: .number.precision(.fractionLength(0)))))
                    
                    Text(workoutManager.heartRate.formatted(.number.precision(.fractionLength(0))) + " bpm").foregroundColor(.red)
                    ;Image(systemName: "heart").foregroundColor(.red) //want this to be inline with bpm
                    
                    Text(workoutManager.stepCount.formatted(.number.precision(.fractionLength(0))) + " steps") 
                    //Text("\(workoutManager.stepCount!) steps"); Image(systemName: "shoe")
//                    Text(Measurement(value: workoutManager.stepCount ?? 0, unit: UnitLength.meters).formatted(.measurement(width: .abbreviated, usage: .road)) + "steps")
                    
                    Text(Measurement(value: workoutManager.distance, unit: UnitLength.meters).formatted(.measurement(width: .abbreviated, usage: .road))) //session distance
                    

                }
            }
            .font(.system(.title, design: .rounded).monospacedDigit().lowercaseSmallCaps())
            .frame(maxWidth: .infinity, alignment: .leading)
            .ignoresSafeArea(edges: .bottom)
            .scenePadding()
        }
    }
}

struct MetricsView_Previews: PreviewProvider {
    static var previews: some View {
        MetricsView().environmentObject(WorkoutManager())
    }
}

private struct MetricsTimelineSchedule: TimelineSchedule {
    var startDate: Date

    init(from startDate: Date) {
        self.startDate = startDate
    }

    func entries(from startDate: Date, mode: TimelineScheduleMode) -> PeriodicTimelineSchedule.Entries {
        PeriodicTimelineSchedule(from: self.startDate, by: (mode == .lowFrequency ? 1.0 : 1.0 / 30.0))
            .entries(from: startDate, mode: mode)
    }
}
