//
//  SessionPagingView.swift
//  CapstoneProject WatchKit Extension
//
//  Created by Easten Wember on 2/25/22.
//
//session paging view with tab view to display different session views

import SwiftUI
import WatchKit

struct SessionPagingView: View {
    @EnvironmentObject var workoutManager: WorkoutManager //give sessionPagingView access to WorkoutManager env. var
    @Environment(\.isLuminanceReduced) var isLuminanceReduced //effects lighting of screen if watch is raised or not
    @State private var selection: Tab = .metrics //provide binding for tabView selection...default show metrics screen

    //model each view that can be selected in tabView
    enum Tab { //holds each possible view to display
        case controls, metrics, nowPlaying
    }

    var body: some View {
        TabView(selection: $selection) { //selection parameter uses binding for selection State Variable
            ControlsView().tag(Tab.controls) //tags let views be selected
            MetricsView().tag(Tab.metrics)
            NowPlayingView().tag(Tab.nowPlaying) //SwuiftUIO view provided by watchkit
        }
        //.navigationTitle(workoutManager.selectedWorkout?.name ?? "") //title = WorkoutManager's selected workout name
        .navigationBarBackButtonHidden(true) //don't want user to go back to startView, need to end session
        .navigationBarHidden(selection == .nowPlaying) //hide nav bar when on nowPlaying view
        .navigationBarHidden(selection == .metrics) //hide nav bar when on metrics view
        .navigationBarHidden(selection == .controls)
        
        .onChange(of: workoutManager.running) { _ in //when pause/unpause session running status changes. automatically display metricsView
            displayMetricsView()
        }
        .tabViewStyle(PageTabViewStyle(indexDisplayMode: isLuminanceReduced ? .never : .automatic))
        .onChange(of: isLuminanceReduced) { _ in //change brightness/display of screen?
            displayMetricsView()
        }
    }

    private func displayMetricsView() { //animate switch to metrics view if session pauses
        withAnimation {
            selection = .metrics
        }
    }
}

struct PagingView_Previews: PreviewProvider {
    static var previews: some View {
        SessionPagingView().environmentObject(WorkoutManager())
    }
}
