//
//  ContentView.swift
//  CapstoneProject WatchKit Extension
//
//  Created by Easten Wember on 2/25/22.
//
// StartView give carosuel style layout to display opening session options to users

import SwiftUI
import HealthKit //get access to HKWorkoutActivityType
import UserNotifications //give access to local notifications


struct StartView: View {
    @EnvironmentObject var workoutManager: WorkoutManager //StartView navigationLink needs to bind its selection to workoutmanager's selected workout
    
//user if ok to push notifications
    let center: Void = UNUserNotificationCenter.current()
        .requestAuthorization(options: [.alert, .badge, .sound]) { (granted, error) in
        if granted {
            print("Allowed to send notifications!")
        } else {
            print("Rut Roh not allowed...")
        }
    }//end authorization request
    
    //types of workouts to be displayed in startView's list ...
//    var workoutTypes: [HKWorkoutActivityType] = [.cycling, .running, .walking]
    var workoutTypes: [HKWorkoutActivityType] = [.walking] //when user starts a session, stats will be in "other" category, dont really need a workout perse, just the stats in a session

    var body: some View {
        //ListView to display session type(s)
        List(workoutTypes) { workoutType in
            //navigationLink for each workoutType..gives destination for based interface
            NavigationLink(workoutType.name,
                           destination: SessionPagingView(), //Navigation goes to sessionPaging
                           tag: workoutType, //tag = workoutType selected
                           selection: $workoutManager.selectedWorkout) //binding to selectedWorkout on workoutManager
                .padding(EdgeInsets(top: 15, leading: 5, bottom: 15, trailing: 5))
        }
        .listStyle(.carousel)
        .navigationBarTitle("Workouts")
        .onAppear {
            workoutManager.requestAuthorization() //!! request authorization when startView apparts
        }
    }
}

struct StartView_Previews: PreviewProvider {
    static var previews: some View {
        StartView().environmentObject(WorkoutManager())
    }
}

//Make HKWorkoutActivityType accessible to workoutTypes list,
//extend HKWorkoutActivityType enum to conform to Identifiable, add name variablke to those in lisr
extension HKWorkoutActivityType: Identifiable {
    public var id: UInt { //id computed variable returns raw value of enum (whats tapped on screen??)
        rawValue
    }

    //name switch through cases to return name(session type)
    var name: String {
        switch self {
        case .walking:
            return "Start a Session"
//        case .walking:
//            return "Walk"
        default:
            return ""
        }
    }
}


